@@ -8,7 +8,7 @@ Usage::
     data: ArrayValueTypeDef = {...}
 """
 import sys
-from typing import IO, List, Union
+from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -22,18 +22,18 @@ else:
 
 __all__ = (
     "ArrayValueTypeDef",
+    "ColumnMetadataTypeDef",
     "FieldTypeDef",
+    "RecordTypeDef",
+    "ResultFrameTypeDef",
+    "ResultSetMetadataTypeDef",
+    "SqlStatementResultTypeDef",
+    "StructValueTypeDef",
     "UpdateResultTypeDef",
+    "ValueTypeDef",
     "BatchExecuteStatementResponseTypeDef",
     "BeginTransactionResponseTypeDef",
     "CommitTransactionResponseTypeDef",
-    "StructValueTypeDef",
-    "ValueTypeDef",
-    "RecordTypeDef",
-    "ColumnMetadataTypeDef",
-    "ResultSetMetadataTypeDef",
-    "ResultFrameTypeDef",
-    "SqlStatementResultTypeDef",
     "ExecuteSqlResponseTypeDef",
     "ExecuteStatementResponseTypeDef",
     "ResultSetOptionsTypeDef",
@@ -53,61 +53,6 @@ ArrayValueTypeDef = TypedDict(
     total=False,
 )
 
-FieldTypeDef = TypedDict(
-    "FieldTypeDef",
-    {
-        "arrayValue": ArrayValueTypeDef,
-        "blobValue": Union[bytes, IO],
-        "booleanValue": bool,
-        "doubleValue": float,
-        "isNull": bool,
-        "longValue": int,
-        "stringValue": str,
-    },
-    total=False,
-)
-
-UpdateResultTypeDef = TypedDict(
-    "UpdateResultTypeDef", {"generatedFields": List[FieldTypeDef]}, total=False
-)
-
-BatchExecuteStatementResponseTypeDef = TypedDict(
-    "BatchExecuteStatementResponseTypeDef",
-    {"updateResults": List[UpdateResultTypeDef]},
-    total=False,
-)
-
-BeginTransactionResponseTypeDef = TypedDict(
-    "BeginTransactionResponseTypeDef", {"transactionId": str}, total=False
-)
-
-CommitTransactionResponseTypeDef = TypedDict(
-    "CommitTransactionResponseTypeDef", {"transactionStatus": str}, total=False
-)
-
-StructValueTypeDef = TypedDict(
-    "StructValueTypeDef", {"attributes": List[ValueTypeDef]}, total=False
-)
-
-ValueTypeDef = TypedDict(
-    "ValueTypeDef",
-    {
-        "arrayValues": List["ValueTypeDef"],
-        "bigIntValue": int,
-        "bitValue": bool,
-        "blobValue": Union[bytes, IO],
-        "doubleValue": float,
-        "intValue": int,
-        "isNull": bool,
-        "realValue": float,
-        "stringValue": str,
-        "structValue": StructValueTypeDef,
-    },
-    total=False,
-)
-
-RecordTypeDef = TypedDict("RecordTypeDef", {"values": List[ValueTypeDef]}, total=False)
-
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
@@ -129,37 +74,92 @@ ColumnMetadataTypeDef = TypedDict(
     total=False,
 )
 
-ResultSetMetadataTypeDef = TypedDict(
-    "ResultSetMetadataTypeDef",
-    {"columnCount": int, "columnMetadata": List[ColumnMetadataTypeDef]},
+FieldTypeDef = TypedDict(
+    "FieldTypeDef",
+    {
+        "arrayValue": "ArrayValueTypeDef",
+        "blobValue": bytes,
+        "booleanValue": bool,
+        "doubleValue": float,
+        "isNull": bool,
+        "longValue": int,
+        "stringValue": str,
+    },
     total=False,
 )
 
+RecordTypeDef = TypedDict("RecordTypeDef", {"values": List["ValueTypeDef"]}, total=False)
+
 ResultFrameTypeDef = TypedDict(
     "ResultFrameTypeDef",
-    {"records": List[RecordTypeDef], "resultSetMetadata": ResultSetMetadataTypeDef},
+    {"records": List["RecordTypeDef"], "resultSetMetadata": "ResultSetMetadataTypeDef"},
+    total=False,
+)
+
+ResultSetMetadataTypeDef = TypedDict(
+    "ResultSetMetadataTypeDef",
+    {"columnCount": int, "columnMetadata": List["ColumnMetadataTypeDef"]},
     total=False,
 )
 
 SqlStatementResultTypeDef = TypedDict(
     "SqlStatementResultTypeDef",
-    {"numberOfRecordsUpdated": int, "resultFrame": ResultFrameTypeDef},
+    {"numberOfRecordsUpdated": int, "resultFrame": "ResultFrameTypeDef"},
     total=False,
 )
 
+StructValueTypeDef = TypedDict(
+    "StructValueTypeDef", {"attributes": List["ValueTypeDef"]}, total=False
+)
+
+UpdateResultTypeDef = TypedDict(
+    "UpdateResultTypeDef", {"generatedFields": List["FieldTypeDef"]}, total=False
+)
+
+ValueTypeDef = TypedDict(
+    "ValueTypeDef",
+    {
+        "arrayValues": List["ValueTypeDef"],
+        "bigIntValue": int,
+        "bitValue": bool,
+        "blobValue": bytes,
+        "doubleValue": float,
+        "intValue": int,
+        "isNull": bool,
+        "realValue": float,
+        "stringValue": str,
+        "structValue": "StructValueTypeDef",
+    },
+    total=False,
+)
+
+BatchExecuteStatementResponseTypeDef = TypedDict(
+    "BatchExecuteStatementResponseTypeDef",
+    {"updateResults": List["UpdateResultTypeDef"]},
+    total=False,
+)
+
+BeginTransactionResponseTypeDef = TypedDict(
+    "BeginTransactionResponseTypeDef", {"transactionId": str}, total=False
+)
+
+CommitTransactionResponseTypeDef = TypedDict(
+    "CommitTransactionResponseTypeDef", {"transactionStatus": str}, total=False
+)
+
 ExecuteSqlResponseTypeDef = TypedDict(
     "ExecuteSqlResponseTypeDef",
-    {"sqlStatementResults": List[SqlStatementResultTypeDef]},
+    {"sqlStatementResults": List["SqlStatementResultTypeDef"]},
     total=False,
 )
 
 ExecuteStatementResponseTypeDef = TypedDict(
     "ExecuteStatementResponseTypeDef",
     {
-        "columnMetadata": List[ColumnMetadataTypeDef],
-        "generatedFields": List[FieldTypeDef],
+        "columnMetadata": List["ColumnMetadataTypeDef"],
+        "generatedFields": List["FieldTypeDef"],
         "numberOfRecordsUpdated": int,
-        "records": List[List[FieldTypeDef]],
+        "records": List[List["FieldTypeDef"]],
     },
     total=False,
 )
@@ -179,7 +179,7 @@ SqlParameterTypeDef = TypedDict(
     {
         "name": str,
         "typeHint": Literal["DATE", "DECIMAL", "TIME", "TIMESTAMP"],
-        "value": FieldTypeDef,
+        "value": "FieldTypeDef",
     },
     total=False,
 )
